@@ -1,7 +1,7 @@
 # model parameters ---------------------
 
 
-#' @rdname model_parameters.default
+#' @rdname model_parameters.averaging
 #' @export
 model_parameters.logitor <- function(model,
                                      ci = .95,
@@ -9,7 +9,6 @@ model_parameters.logitor <- function(model,
                                      iterations = 1000,
                                      standardize = NULL,
                                      exponentiate = TRUE,
-                                     robust = FALSE,
                                      p_adjust = NULL,
                                      verbose = TRUE,
                                      ...) {
@@ -20,22 +19,23 @@ model_parameters.logitor <- function(model,
     iterations = iterations,
     standardize = standardize,
     exponentiate = exponentiate,
-    robust = robust,
     p_adjust = p_adjust,
     ...
   )
 }
 
 
+#' @rdname model_parameters.averaging
 #' @export
 model_parameters.poissonirr <- model_parameters.logitor
 
 
+#' @rdname model_parameters.averaging
 #' @export
 model_parameters.negbinirr <- model_parameters.logitor
 
 
-#' @rdname model_parameters.default
+#' @rdname model_parameters.averaging
 #' @export
 model_parameters.poissonmfx <- function(model,
                                         ci = .95,
@@ -44,7 +44,6 @@ model_parameters.poissonmfx <- function(model,
                                         component = c("all", "conditional", "marginal"),
                                         standardize = NULL,
                                         exponentiate = FALSE,
-                                        robust = FALSE,
                                         p_adjust = NULL,
                                         verbose = TRUE,
                                         ...) {
@@ -58,7 +57,6 @@ model_parameters.poissonmfx <- function(model,
     standardize = standardize,
     exponentiate = exponentiate,
     component = component,
-    robust = robust,
     p_adjust = p_adjust,
     ...
   )
@@ -68,18 +66,22 @@ model_parameters.poissonmfx <- function(model,
 }
 
 
+#' @rdname model_parameters.averaging
 #' @export
 model_parameters.logitmfx <- model_parameters.poissonmfx
 
 
+#' @rdname model_parameters.averaging
 #' @export
 model_parameters.probitmfx <- model_parameters.poissonmfx
 
 
+#' @rdname model_parameters.averaging
 #' @export
 model_parameters.negbinmfx <- model_parameters.poissonmfx
 
 
+#' @rdname model_parameters.averaging
 #' @export
 model_parameters.betaor <- function(model,
                                     ci = .95,
@@ -106,7 +108,7 @@ model_parameters.betaor <- function(model,
 }
 
 
-#' @rdname model_parameters.default
+#' @rdname model_parameters.averaging
 #' @export
 model_parameters.betamfx <- function(model,
                                      ci = .95,
@@ -115,7 +117,6 @@ model_parameters.betamfx <- function(model,
                                      component = c("all", "conditional", "precision", "marginal"),
                                      standardize = NULL,
                                      exponentiate = FALSE,
-                                     robust = FALSE,
                                      p_adjust = NULL,
                                      verbose = TRUE,
                                      ...) {
@@ -129,7 +130,6 @@ model_parameters.betamfx <- function(model,
     standardize = standardize,
     exponentiate = exponentiate,
     component = component,
-    robust = robust,
     p_adjust = p_adjust,
     ...
   )
@@ -145,8 +145,8 @@ model_parameters.betamfx <- function(model,
 
 
 #' @export
-ci.logitor <- function(x, ci = .95, method = NULL, robust = FALSE, ...) {
-  .ci_generic(model = x$fit, ci = ci, method = method, robust = robust, ...)
+ci.logitor <- function(x, ci = .95, method = NULL, ...) {
+  .ci_generic(model = x$fit, ci = ci, method = method, ...)
 }
 
 
@@ -163,10 +163,9 @@ ci.poissonmfx <- function(x,
                           ci = .95,
                           component = c("all", "conditional", "marginal"),
                           method = NULL,
-                          robust = FALSE,
                           ...) {
   component <- match.arg(component)
-  .ci_generic(model = x, ci = ci, component = component, method = method, robust = robust, ...)
+  .ci_generic(model = x, ci = ci, component = component, method = method, ...)
 }
 
 
@@ -196,11 +195,10 @@ ci.betaor <- function(x,
 ci.betamfx <- function(x,
                        ci = .95,
                        method = NULL,
-                       robust = FALSE,
                        component = c("all", "conditional", "precision", "marginal"),
                        ...) {
   component <- match.arg(component)
-  .ci_generic(model = x, ci = ci, component = component, method = method, robust = robust, ...)
+  .ci_generic(model = x, ci = ci, component = component, method = method, ...)
 }
 
 
@@ -215,7 +213,7 @@ standard_error.negbin <- standard_error.default
 
 #' @export
 standard_error.logitor <- function(model, ...) {
-  standard_error.lm(model$fit, ...)
+  standard_error.default(model$fit, ...)
 }
 
 
@@ -227,10 +225,9 @@ standard_error.poissonirr <- standard_error.logitor
 standard_error.negbinirr <- standard_error.logitor
 
 
-#' @rdname standard_error
 #' @export
 standard_error.poissonmfx <- function(model,
-                                      component = c("all", "conditional", "marginal"),
+                                      component = "all",
                                       ...) {
   parms <- insight::get_parameters(model, component = "all")
   cs <- stats::coef(summary(model$fit))
@@ -242,7 +239,7 @@ standard_error.poissonmfx <- function(model,
     Component = parms$Component
   )
 
-  component <- match.arg(component)
+  component <- match.arg(component, choices = c("all", "conditional", "marginal"))
   if (component != "all") {
     out <- out[out$Component == component, ]
   }
@@ -272,10 +269,9 @@ standard_error.betaor <- function(model,
 }
 
 
-#' @rdname standard_error
 #' @export
 standard_error.betamfx <- function(model,
-                                   component = c("all", "conditional", "precision", "marginal"),
+                                   component = "all",
                                    ...) {
   parms <- insight::get_parameters(model, component = "all")
   cs <- do.call(rbind, stats::coef(summary(model$fit)))
@@ -287,7 +283,7 @@ standard_error.betamfx <- function(model,
     Component = parms$Component
   )
 
-  component <- match.arg(component)
+  component <- match.arg(component, choices = c("all", "conditional", "precision", "marginal"))
   if (component != "all") {
     out <- out[out$Component == component, ]
   }
@@ -347,7 +343,7 @@ degrees_of_freedom.betamfx <- degrees_of_freedom.logitor
 #' p-values for Marginal Effects Models
 #'
 #' This function attempts to return, or compute, p-values of marginal effects
-#' models from package \pkg{mfx}.
+#' models from package **mfx**.
 #'
 #' @param model A statistical model.
 #' @param component Should all parameters, parameters for the conditional model,
